@@ -23,20 +23,20 @@ plot.multiMCA <- function(x,type='v',axes=c(1,2),points='all',threshold=2.58,gro
 	}
       }
     }
-  if (type %in% c('i','inames')) { # new
+  if (type %in% c('i','inames')) {
     cmin <- apply(x$ind$coord[,axes],2,min)*1.1
     cmax <- apply(x$ind$coord[,axes],2,max)*1.1
     clim <- cbind(cmin,cmax)
-    ni <- nrow(x$ind$coord) # new
-    if(points=='all') condi <- 1:ni # new
-    if (points=='besth') condi <- x$ind$contrib[,axes[1]]>=100/ni # new
-    if (points=='bestv') condi <- x$ind$contrib[,axes[2]]>=100/ni # new
-    if (points=='best') condi <- x$ind$contrib[,axes[1]]>=100/ni | x$ind$contrib[,axes[2]]>=100/ni # new
-    coord <- x$ind$coord[condi,axes] # new
-    if(type=='i') pcol <- col #new
-    if(type=='inames') pcol <- 'white' #new
-    plot(coord,col=pcol,xlim=clim[1,],ylim=clim[2,],xlab=tit1,ylab=tit2,pch=19,cex=0.2,...) #new
-    if(type=='inames') text(coord,rownames(coord),col=col) #new
+    ni <- nrow(x$ind$coord)
+    if(points=='all') condi <- 1:ni 
+    if (points=='besth') condi <- x$ind$contrib[,axes[1]]>=100/ni 
+    if (points=='bestv') condi <- x$ind$contrib[,axes[2]]>=100/ni 
+    if (points=='best') condi <- x$ind$contrib[,axes[1]]>=100/ni | x$ind$contrib[,axes[2]]>=100/ni 
+    coord <- x$ind$coord[condi,axes] 
+    if(type=='i') pcol <- col 
+    if(type=='inames') pcol <- 'white' 
+    plot(coord,col=pcol,xlim=clim[1,],ylim=clim[2,],xlab=tit1,ylab=tit2,pch=19,cex=0.2,...) 
+    if(type=='inames') text(coord,rownames(coord),col=col) 
     abline(h=0,v=0,col='grey')
     }
 }
